==> kbibtex-0.1.1.tar.bz2: kbibtex-0.1.1/src/kbibtexlistview.h <==
/***************************************************************************
*   Copyright (C) 2004-2005 by Thomas Fischer                             *
*   fischer@unix-ag.uni-kl.de                                             *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/
#ifndef KBIBTEXLISTVIEW_H
#define KBIBTEXLISTVIEW_H

#include <klistview.h>

class QString;
class KBibTeXPart;
class KBibTeXListViewItem;
class BibTeXFile;

static const QString Columns[] =
    {
        QString( i18n( "Type" ) ), QString( i18n( "Id" ) ), QString( i18n( "Title" ) ), QString( i18n( "Author/Editor/Publisher" ) ), QString( i18n( "Year" ) )
    };
static const int ColumnsCount = sizeof( Columns ) / sizeof( Columns[ 0 ] );

class KBibTeXListView : public KListView
{
    Q_OBJECT
public:
    KBibTeXListView( KBibTeXPart *kbibtexPart, QWidget *parent = 0, const char *name = 0 );
    ~KBibTeXListView();

    void setBibTexFile( BibTeXFile *bibtexFile );
    void updateView( KBibTeXListViewItem *item = NULL );
    BibTeXFile *selectedElements();

public slots:
    void filterText( const QString& text );

private slots:
    void setSortingColumn( int column );

protected:
    void resizeEvent ( QResizeEvent * e );
    void contentsDragEnterEvent( QDragEnterEvent *e );
    void contentsDropEvent( QDropEvent *e );

private:
    KBibTeXPart *m_kbibtexPart;
    BibTeXFile *m_bibtexFile;
    QString m_filter;

    void clearAll();
};

#endif

==> kbibtex-0.1.2.tar.bz2: kbibtex-0.1.2/src/kbibtexlistview.h <==
/***************************************************************************
*   Copyright (C) 2004-2005 by Thomas Fischer                             *
*   fischer@unix-ag.uni-kl.de                                             *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/
#ifndef KBIBTEXLISTVIEW_H
#define KBIBTEXLISTVIEW_H

#include <klistview.h>

class QString;
class KBibTeXPart;
class KBibTeXListViewItem;
class BibTeXFile;

static const QString Columns[] =
    {
        QString( i18n( "Type" ) ), QString( i18n( "Id" ) ), QString( i18n( "Title" ) ), QString( i18n( "Author/Editor/Publisher" ) ), QString( i18n( "Year" ) )
    };
static const int ColumnsCount = sizeof( Columns ) / sizeof( Columns[ 0 ] );

class KBibTeXListView : public KListView
{
    Q_OBJECT
public:
    KBibTeXListView( KBibTeXPart *kbibtexPart, QWidget *parent = 0, const char *name = 0 );
    ~KBibTeXListView();

    void setBibTexFile( BibTeXFile *bibtexFile );
    void updateView( KBibTeXListViewItem *item = NULL );
    BibTeXFile *selectedElements();
    void enabledActions();
    bool KBibTeXListView::acceptDrag( QDropEvent *event ) const;

public slots:
    void filterText( const QString&text );

private slots:
    void setSortingColumn( int column );
    void columnSizeChange();

protected:
    //     void resizeEvent( QResizeEvent * e );
    void dragEnterEvent( QDragEnterEvent *e );
    void contentsDragEnterEvent( QDragEnterEvent *e );
    void dropEvent( QDropEvent *e );
    void contentsDropEvent( QDropEvent *e );
    void startDrag();

private:
    KBibTeXPart *m_kbibtexPart;
    BibTeXFile *m_bibtexFile;
    QString m_filter;

    void clearAll();
};

#endif
